import numpy as np
import tensorflow as tf
from tensorflow import keras

fashion_mnist = keras.datasets.fashion_mnist

(X_train, Y_train), (X_test, Y_test) = fashion_mnist.load_data()

X_train, X_test = X_train / 255.0, X_test / 255.0

model = keras.Sequential([
  keras.layers.Flatten(input_shape=(28, 28)),
  keras.layers.Dense(128, activation=tf.nn.relu),
  keras.layers.Dropout(0.25),
  keras.layers.Dense(10, activation=tf.nn.softmax)
])

model.compile(optimizer=tf.compat.v1.train.AdamOptimizer(), 
    loss='sparse_categorical_crossentropy',
    metrics=['accuracy'])

model.fit(X_train, Y_train, epochs=10)
loss, acc = model.evaluate(X_test, Y_test)

print('loss:', loss, 'accuracy:', acc)

predictions = model.predict(X_test)


class_names = [
  'Tシャツ', 'パンツ', 
  'プルオーバー', 'ドレス', 
  'コート', 'サンダル', 
  'シャツ', 'スニーカー', 
  'バッグ', 'ブーツ']


for i in range(10):
  print("{}\t({}, {:0.1f}%)".format(class_names[np.argmax(predictions[i])], 
    class_names[Y_test[i]], max(predictions[i])*100))

