import matplotlib.pyplot as plt # 図示に用いる
import numpy as np
import tensorflow as tf
from tensorflow import keras
# macOSなどで警告表示時は下記2行のコメントを外して実行
import os
os.environ['KMP_DUPLICATE_LIB_OK'] = 'True'

fashion_mnist = keras.datasets.fashion_mnist

(X_train, Y_train), (X_test, Y_test) = fashion_mnist.load_data()

X_train, X_test = X_train / 255.0, X_test / 255.0

model = keras.Sequential([
  keras.layers.Flatten(input_shape=(28, 28)),
  keras.layers.Dense(128, activation=tf.nn.relu),
  keras.layers.Dropout(0.25),
  keras.layers.Dense(10, activation=tf.nn.softmax)
])

model.compile(optimizer=tf.compat.v1.train.AdamOptimizer(), 
    loss='sparse_categorical_crossentropy',
    metrics=['accuracy'])

model.fit(X_train, Y_train, epochs=10)
loss, acc = model.evaluate(X_test, Y_test)

print('loss:', loss, 'accuracy:', acc)

predictions = model.predict(X_test)

class_names = [
  'T-shirt', 'Pants', 
  'Pullovr', 'Dress', 
  'Coat', 'Sandal', 
  'Shirt', 'Sneaker', 
  'Bag', 'Boot']


for i in range(10):
  print("{}\t({}, {:0.1f}%)".format(class_names[np.argmax(predictions[i])], 
    class_names[Y_test[i]], max(predictions[i])*100))


# フォント出力の都合で英語表記に
class_names = [
  'T-shirt', 'Pants', 
  'Pullovr', 'Dress', 
  'Coat', 'Sandal', 
  'Shirt', 'Sneaker', 
  'Bag', 'Boot']


for i in range(10):
  print("{}\t({}, {:0.1f}%)".format(class_names[np.argmax(predictions[i])], 
    class_names[Y_test[i]], max(predictions[i])*100))


cols = 5
rows = 2
num_img = rows * cols
plt.figure(figsize=(cols, rows))


for i in range(num_img):
  plt.subplot(rows, cols, i + 1)
  pred_arr, label, img = \
      predictions[i], Y_test[i], X_test[i]
  plt.grid(False)
  plt.xticks([])
  plt.yticks([])
  
  plt.imshow(img, cmap=plt.cm.binary)


  pred_label = np.argmax(pred_arr)
  if pred_label == label:
    color = 'blue'
  else:
    color = 'red'
  
  plt.xlabel("{} {:1.0f}% ({})"
      .format(class_names[pred_label],
          100*np.max(pred_arr),
          class_names[label]),
          color=color)


plt.show()

