import numpy as np
import tensorflow as tf
from tensorflow import keras
import os.path # Windows/macOS感でファイル名を適切に処理するのに必要

fashion_mnist = keras.datasets.fashion_mnist
(X_train, Y_train), (X_test, Y_test) \
        = fashion_mnist.load_data()
X_train, X_test = X_train / 255.0, X_test / 255.0
model = keras.Sequential([
    keras.layers.Flatten(input_shape=(28, 28)),
    keras.layers.Dense(128, activation=tf.nn.relu),
    keras.layers.Dropout(0.25),
    keras.layers.Dense(10, activation=tf.nn.softmax)
    ])
model.compile(optimizer=tf.train.AdamOptimizer(),
        loss='sparse_categorical_crossentropy',
        metrics=['accuracy'])
# TensorBoardを使うための定義、os.path.abspathでOSを問わずフォルダ名を利用
callback = keras.callbacks.TensorBoard( \
        log_dir=os.path.abspath("./tf_log/"), histogram_freq=1) # model.fit時にcallbackからTensorBoardを呼び出す
model.fit(X_train, Y_train, \
        epochs=10, \
        callbacks=[callback], \
       validation_data=(X_test, Y_test))

loss, acc = model.evaluate(X_test, Y_test)

print('loss:', loss, 'accuracy:', acc)

predictions = model.predict(X_test)

class_names = ['Tシャツ', 'パンツ', 'プルオーバー', 'ドレス', 'コート', 'サンダル', 'シャツ', 'スニーカー', 'バッグ', 'ブーツ']

for i in range(10):
    print("{}\t({}, {:0.1f}%)".format(class_names[np.argmax(predictions[i])],
        class_names[Y_test[i]], max(predictions[i])*100))
